@@ -4,20 +4,39 @@ import os
 import click
 import msal
 import requests
+from time import sleep
 
-from .config import get_config_path, get_api_config, get_token_path, ARCHIMEDES_CONF_DIR
+from .config import (
+    get_config_path,
+    get_api_config,
+    get_token_path,
+    ARCHIMEDES_CONF_DIR,
+)
 from .token_cache import get_token_cache
 
 AUTH_ACTIONS_LOGIN = "login"
 AUTH_ACTIONS_LOGOUT = "logout"
 AUTH_ACTIONS_GET_TOKEN = "get-token"
+AUTH_ACTIONS_SHOW = "show"
 AUTH_ACTIONS = [
     AUTH_ACTIONS_LOGIN,
     AUTH_ACTIONS_LOGOUT,
     AUTH_ACTIONS_GET_TOKEN,
+    AUTH_ACTIONS_SHOW,
 ]
 
 
+def get_accepted_env():
+    for _ in range(0, 10):
+        try:
+            response = requests.get(
+                "https://arclconfig.azureedge.net/config.json"
+            ).json()
+            return tuple(response.keys())
+        except:
+            sleep(3)
+    raise Exception("Unable to get config from arclconfig.")
+
 class ArchimedesAuth:
     def __init__(self, env):
         self.env = env
@@ -33,6 +52,15 @@ class ArchimedesAuth:
             f"api://{self.api_config.aad_app_client_id}/.default",
         ]
 
+    def get_token_expiry(self):
+        accounts = self.app.get_accounts()
+        if not accounts:
+            return None
+
+        chosen = accounts[0]
+        result = self.app.acquire_token_silent(self.get_scopes(), account=chosen)
+        return result["expires_in"]
+
     def get_access_token_silent(self):
         # We now check the cache to see
         # whether we already have some accounts that the end user already used to sign in before.
@@ -108,6 +136,44 @@ class ArchimedesAuth:
             open(self.saved_config_path, "w").write(config_json)
             click.echo(f"Login successful into env: {self.env}")
 
+    @staticmethod
+    def show():
+        all_env_details = {}
+        for env in get_accepted_env():
+            saved_config_path = get_config_path(env)
+            if not os.path.exists(saved_config_path):
+                continue
+            with open(saved_config_path, "r") as file:
+                config = json.load(file)
+            all_env_details[env] = config["user"]
+
+        if not len(all_env_details):
+            click.echo("No accounts logged in.")
+            return
+        click.echo("Details of all accounts are below.")
+        sep = "   "
+        dp_color = "blue"
+        for env, config in all_env_details.items():
+            click.echo("")
+            click.echo(sep + click.style("ENVIRONMENT:", fg=dp_color) + f"{env}")
+            click.echo(
+                sep * 2 + click.style("Name:", fg=dp_color) + f" {config['name']}"
+            )
+            click.echo(
+                sep * 2
+                + click.style("Username:", fg=dp_color)
+                + f" {config['username']}"
+            )
+            click.echo(
+                sep * 2 + click.style("Email:", fg=dp_color) + f" {config['email']}"
+            )
+            app = ArchimedesAuth(env)
+            click.echo(
+                sep * 2
+                + click.style("Token expires in:", fg=dp_color)
+                + f" {app.get_token_expiry()} seconds"
+            )
+
     def logout(self):
         # remove older tokens created on previous versions
         for file_to_remove in (
