@@ -1,10 +1,10 @@
 #!/usr/bin/env python
-import json
 import os
 import re
 import socketserver
 import subprocess
 import sys
+import json
 from http.server import SimpleHTTPRequestHandler
 
 import click
@@ -17,7 +17,9 @@ from .auth import (
     AUTH_ACTIONS_GET_TOKEN,
     AUTH_ACTIONS_LOGIN,
     AUTH_ACTIONS_LOGOUT,
+    AUTH_ACTIONS_SHOW,
     ArchimedesAuth,
+    get_accepted_env,
 )
 from .config import get_config_path
 
@@ -82,10 +84,17 @@ def _get_version_from_python_version_string(version_string):
     return f"{result_dict['major']}.{result_dict['minor']}.{result_dict['patch']}"
 
 
-def get_config(project_name):
+def get_config(project_name, env):
     """Create a config for the project"""
+    if not os.path.exists(get_config_path(env)):
+        raise ConfigNotFoundException(
+            "User not logged in. Please log in using `arcl auth login <organization_id>`."
+        )
+
+    config = json.loads(open(get_config_path(env), "r").read())
     return {
         "project_name": project_name,
+        "author_name": get_author_name(config["user"]),
         "python_version": get_python_version(),
     }
 
@@ -119,7 +128,7 @@ def cli():
     help="Environment to setup",
 )
 def auth(action, organization, env):
-    accepted_env = ("dev", "stage", "prod")
+    accepted_env = get_accepted_env()
     if env not in accepted_env:
         raise ClickException(f"env should be one of {accepted_env}")
 
@@ -136,6 +145,9 @@ def auth(action, organization, env):
     if action.lower() == AUTH_ACTIONS_GET_TOKEN:
         click.echo(archimedes_auth.get_access_token())
 
+    if action.lower() == AUTH_ACTIONS_SHOW:
+        click.echo(archimedes_auth.show())
+
 
 # remove the examples flag
 # create /production/sample.py instead from the other repo
@@ -143,6 +155,7 @@ def auth(action, organization, env):
 # does adding more PriceAreas increase the precision?
 @cli.command(hidden=True)
 @click.argument("name", required=True)
+@click.argument("env", required=False)
 # @click.option(
 #     "--examples",
 #     is_flag=True,
@@ -157,7 +170,7 @@ def auth(action, organization, env):
     f"{COOKIECUTTER_TEMPLATE_GIT_URL}",
     default=None,
 )
-def new(name, template_version):
+def new(name, template_version, env="prod"):
     """"""
     # if examples == True:
     #     examples_ = "yes"
@@ -168,7 +181,7 @@ def new(name, template_version):
         project_dir = cookiecutter(
             COOKIECUTTER_TEMPLATE_GIT_URL,
             checkout=template_version,
-            extra_context=get_config(name),
+            extra_context=get_config(name, env),
             no_input=True,
         )
     except ConfigNotFoundException as e:
