@@ -4,7 +4,7 @@ from msal_extensions import (
     PersistedTokenCache,
 )
 
-from .config import SAVED_MSAL_TOKEN_CACHE_PATH
+from .config import get_token_path
 
 
 def build_persistence(location, fallback_to_plaintext=False):
@@ -17,6 +17,7 @@ def build_persistence(location, fallback_to_plaintext=False):
         return FilePersistence(location)
 
 
-persistence = build_persistence(SAVED_MSAL_TOKEN_CACHE_PATH, True)
-
-token_cache = PersistedTokenCache(persistence)
+def get_token_cache(env):
+    persistence = build_persistence(get_token_path(env), True)
+    token_cache = PersistedTokenCache(persistence)
+    return token_cache
